import logging
import time
try: from definitions_prod import *
except Exception as e: pass # Surpass error. Note: Create definitions_prod.py

class LoggerUtils:

    def __init__(self, file_name='log_', gui=None, datefmt='%d-%b %H:%M:%S'):
        rootLogger = logging.getLogger()
        self.logger = rootLogger
        self.gui = gui

        if not rootLogger.hasHandlers():
            time.strftime("%Y-%m-%d")

            if '/' not in file_name:
                file_name = appConfig.LOG_PATH + '/' + file_name

            log_file = file_name + '_' + time.strftime("%Y-%m-%d") + '.log'

            logFormatter = logging.Formatter("%(asctime)s  %(levelname)s  %(message)s", datefmt=datefmt)

            rootLogger.setLevel(level=logging.INFO)

            fileHandler = logging.FileHandler(log_file, encoding='UTF-8')
            fileHandler.setFormatter(logFormatter)
            rootLogger.addHandler(fileHandler)

            consoleHandler = logging.StreamHandler()
            consoleHandler.setFormatter(logFormatter)
            rootLogger.addHandler(consoleHandler)

    def _get_text(self, text, *args):
        if args:
            text = str(text) + ' ' + ' '.join([str(arg) for arg in args])
        return text

    def info(self, text, *args):
        text = self._get_text(text, *args)
        self.logger.info(text)

        if self.gui:
            self.gui.send_text_info(text)

    def debug(self, text, *args):
        text = self._get_text(text, *args)

        self.logger.debug(text)
        if self.gui:
            self.gui.send_error_info(text)

    def error(self, text, *args):
        text = self._get_text(text, *args)

        self.logger.error(text)
        if self.gui:
            self.gui.send_error_info(text)

    def warn(self, text, *args):
        text = self._get_text(text, *args)

        self.warning(text)

    def warning(self, text, *args):
        text = self._get_text(text, *args)

        self.logger.warning(text)
        if self.gui:
            self.gui.send_error_info(text)

if __name__ == '__main__':
    log = LoggerUtils()
    log.info('test', 'testd')